===============================
config-handle
===============================

.. image:: https://img.shields.io/travis/iansmcf/config-handle.svg
        :target: https://travis-ci.org/iansmcf/config-handle

.. image:: https://img.shields.io/pypi/v/config-handle.svg
        :target: https://pypi.python.org/pypi/config-handle


Get a handle on configuration files

* Free software: BSD license
* Documentation: https://config-handle.readthedocs.org.

Features
--------

* TODO
